@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class DatamigrationConfig(AppConfig):
-    name = 'datamigration'
+    name = "datamigration"
