@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class DeliveryConfig(AppConfig):
-    name = 'delivery'
+    name = "delivery"
