@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class MealConfig(AppConfig):
-    name = 'meal'
+    name = "meal"
