@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class NoteConfig(AppConfig):
-    name = 'note'
+    name = "note"
