@@ -1,32 +1,32 @@
 from django.http import JsonResponse
 
 
-class FormInvalidAjaxableResponseMixin(object):
+class FormInvalidAjaxableResponseMixin:
     """
     Only ajaxable when the form is invalid: returning errors.
     """
+
     def form_invalid(self, form):
-        response = super(
-            FormInvalidAjaxableResponseMixin, self
-        ).form_invalid(form)
+        response = super().form_invalid(form)
         if self.request.is_ajax():
             return JsonResponse(form.errors, status=400)
         else:
             return response
 
 
-class FormValidAjaxableResponseMixin(object):
+class FormValidAjaxableResponseMixin:
     """
     Only ajaxable when the form is valid: returning pk.
     """
+
     def form_valid(self, form):
         # We make sure to call the parent's form_valid() method because
         # it might do some processing (in the case of CreateView, it will
         # call form.save() for example).
-        response = super(FormValidAjaxableResponseMixin, self).form_valid(form)
+        response = super().form_valid(form)
         if self.request.is_ajax():
             data = {
-                'pk': self.object.pk,
+                "pk": self.object.pk,
             }
             return JsonResponse(data)
         else:
@@ -34,11 +34,12 @@ class FormValidAjaxableResponseMixin(object):
 
 
 class AjaxableResponseMixin(
-        FormInvalidAjaxableResponseMixin,
-        FormValidAjaxableResponseMixin):
+    FormInvalidAjaxableResponseMixin, FormValidAjaxableResponseMixin
+):
     """
     Mixin to add AJAX support to a form.
     Must be used with an object-based FormView (e.g. CreateView)
     https://docs.djangoproject.com/ja/1.9/topics/class-based-views/generic-editing/#ajax-example
     """
+
     pass
