@@ -1,3 +1,3 @@
 from .settings_test import *  # noqa
 
-LANGUAGE_CODE = 'fr'
+LANGUAGE_CODE = "fr"
