@@ -3,7 +3,7 @@ from django import template
 register = template.Library()
 
 
-@register.filter(name='get_item')
+@register.filter(name="get_item")
 def get_item(o, key):
     try:
         return o[key]
@@ -11,6 +11,6 @@ def get_item(o, key):
         return None
 
 
-@register.filter(name='alter_field_class')
+@register.filter(name="alter_field_class")
 def alter_field_class(field, css):
     return field.as_widget(attrs={"class": css})
